@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Test::Warnings; # git description: v0.022-4-g2f1e3f3
+package Test::Warnings; # git description: v0.023-4-g213110e
 # ABSTRACT: Test for warnings and the lack of them
 # KEYWORDS: testing tests warnings
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
 use parent 'Exporter';
 use Test::Builder;
@@ -59,7 +59,7 @@ $SIG{__WARN__} = sub {
             and (  (ref $_orig_warn_handler eq 'CODE')
                 or ($_orig_warn_handler ne 'DEFAULT'
                     and $_orig_warn_handler ne 'IGNORE'
-                    and defined &{$_orig_warn_handler}));
+                    and defined &$_orig_warn_handler));
 
         if ($_[0] =~ /\n$/) {
             warn $_[0];
@@ -154,7 +154,7 @@ Test::Warnings - Test for warnings and the lack of them
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
